# unusualvolume

Monitor stock market transactions for unusual volume and (possibly) make millions.

## Demo

![](unusualvolume_demo.gif)

## About

A simple command line tool to retrieve stock market data (US-only) and analyze trading volumes for anomalies.

## Use Cases

1. Mining valuable trading information and getting ahead of possible large changes in stock prices
2. Transaction monitoring for OSINT (open source intelligence) purposes
3. Collecting data to train your own ML model


## Installation

```shell script
$ pip install unusualvolume --upgrade
```

## Usage

```shell script
$ unusualvolume scan
```